/* libppm.h - internal header file for libppm portable pixmap library
*/

#ifndef _LIBPPM_H_
#define _LIBPPM_H_

#include "libpgm.h"

/* Here are some routines internal to the ppm library. */

void
ppm_readppminitrest(FILE *   const file, 
                    int *    const colsP, 
                    int *    const rowsP, 
                    pixval * const maxvalP);

#endif /*_LIBPPM_H_*/
